@@ -16,6 +16,8 @@ void tools_insert_command_output
                             (GtkWindow *win, JamDoc *doc);
 void tools_validate_xml     (GtkWindow *win, JamDoc *doc);
 void tools_ljcut            (GtkWindow *win, JamDoc *doc);
+void tools_lj_repost        (GtkWindow *win, JamDoc *doc);
+void tools_lj_like          (GtkWindow *win, JamDoc *doc);
 void tools_embedded_media   (GtkWindow *win, JamDoc *doc);
 
 #endif /* tools_h */
